$ScanResult class abstract

Implementers

Constructors

$ScanResult()
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
result → Result<DiscoveredDevice, GenericFailure<ScanFailure>?>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyUsing(void mutator(ScanResult$Change change)) → ScanResult
copyWith({Result<DiscoveredDevice, GenericFailure<ScanFailure>?>? result}) → ScanResult
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override