ConnectionStateUpdate class

Status update for a specific BLE device.

Inheritance
Annotations
  • @immutable
  • @FunctionalData.new()

Constructors

ConnectionStateUpdate({required String deviceId, required DeviceConnectionState connectionState, required GenericFailure<ConnectionError>? failure})
const

Properties

connectionState → DeviceConnectionState
final
deviceId → String
final
failure → GenericFailure<ConnectionError>?
Field error is null if there is no error reported.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyUsing(void mutator(ConnectionStateUpdate$Change change)) → ConnectionStateUpdate
inherited
copyWith({String? deviceId, DeviceConnectionState? connectionState, GenericFailure<ConnectionError>? failure}) → ConnectionStateUpdate
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited